@@ -208,11 +208,18 @@ event `on_font_size` will be fired/called (if exists as a method
 of the main app instance). These events don't provide any
 event arguments.
 
-Another app state event gets fired after the app states getting
-retrieved from the app class instance and before they get saved.
-This event has the method name :meth:`on_app_states_save` and
-provides one event argument `app_states` which is a dict of
-type :data:`AppStateType` containing all app states.
+Another event gets fired for each app state value just after the
+app states getting retrieved from the app class instance and
+before they get stored into the main config file.
+
+This method name of this event includes the key/name of the
+app state using the format :meth:`on_app_state_<app_state_key>_save`,
+so e.g. for the app state `flow_id` the method name will result in
+:meth:`on_app_state_flow_id_save`.
+
+The event is taking one event argument with the value of the app state
+and if it returns a value that is not `None` then this value will
+be stored/saved.
 
 
 application flow change events
@@ -367,6 +374,7 @@ class.
 from abc import ABC, abstractmethod
 import re
 import traceback
+from copy import deepcopy
 from typing import Any, Callable, Dict, Tuple, List, Optional, Type, Sequence
 
 from ae.core import stack_var                       # type: ignore
@@ -376,7 +384,7 @@ from ae.console import ConsoleApp                   # type: ignore
 from ae.files import FilesRegister, RegisteredFile  # type: ignore
 
 
-__version__ = '0.0.24'
+__version__ = '0.0.25'
 
 
 AppStateType = Dict[str, Any]                   #: app state config variable type
@@ -646,9 +654,14 @@ class MainAppBase(ConsoleApp, ABC):
 
         app_state = self.retrieve_app_states()
 
-        self.call_method('on_app_states_save', app_state)
-
         for key, state in app_state.items():
+            if isinstance(state, (list, dict)):
+                state = deepcopy(state)
+
+            new_state = self.call_method(f'on_app_state_{key}_save', state)
+            if new_state is not None:
+                state = new_state
+
             if key == 'flow_id' and flow_action(state) != 'focus':
                 state = id_of_flow('', '')
             elif key == 'flow_path':
